@@ -1,5 +1,5 @@
 package Tangerine;
-$Tangerine::VERSION = '0.15';
+$Tangerine::VERSION = '0.16';
 # ABSTRACT: Examine perl files and report dependency metadata
 use 5.010;
 use strict;
@@ -78,7 +78,7 @@ sub run {
             if (my $data = $hook->run($children)) {
                 my $modules = $data->modules;
                 for my $k (keys %$modules) {
-                    if ($k !~ m/^([a-z_][a-z0-9_]*(::)?)+$/io ||
+                    if ($k !~ m/^[a-z_][a-z0-9_]*(::[a-z0-9_]+)*(::)?$/io ||
                         $k =~ m/^__[A-Z]+__$/o) {
                         delete $modules->{$k};
                         next
